@@ -84,4 +84,4 @@ class TestPackDB(TestDBBase):
         # assert num_ambiguous
 
         # non-existing
-        self.failUnlessRaises(BadObject, pdb.partial_to_complete_sha, b'\0\0', 4)
+        self.assertRaises(BadObject, pdb.partial_to_complete_sha, b'\0\0', 4)
